# -*- coding: utf-8 -*-
"""
Exception classes.

.. versionadded:: 1.0.0
"""


class InvalidMethod(Exception):
    """
    Raised when an invalid pydash method is invoked through :func:`pydash.chaining.chain`.

    .. versionadded:: 1.0.0
    """

    pass
